package com.waimai.web.admin.mapper;

import java.util.List;
import com.waimai.web.admin.domain.Orders;
import com.waimai.web.admin.domain.OrderFoods;

/**
 * 订单记录Mapper接口
 * 
 * @author callmeyan
 * @date 2023-03-24
 */
public interface OrdersMapper 
{
    /**
     * 查询订单记录
     * 
     * @param id 订单记录主键
     * @return 订单记录
     */
    public Orders selectOrdersById(String id);

    /**
     * 查询订单记录列表
     * 
     * @param orders 订单记录
     * @return 订单记录集合
     */
    public List<Orders> selectOrdersList(Orders orders);

    /**
     * 新增订单记录
     * 
     * @param orders 订单记录
     * @return 结果
     */
    public int insertOrders(Orders orders);

    /**
     * 修改订单记录
     * 
     * @param orders 订单记录
     * @return 结果
     */
    public int updateOrders(Orders orders);

    /**
     * 删除订单记录
     * 
     * @param id 订单记录主键
     * @return 结果
     */
    public int deleteOrdersById(String id);

    /**
     * 批量删除订单记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrdersByIds(String[] ids);

    /**
     * 批量删除订单商品
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderFoodsByOids(String[] ids);
    
    /**
     * 批量新增订单商品
     * 
     * @param orderFoodsList 订单商品列表
     * @return 结果
     */
    public int batchOrderFoods(List<OrderFoods> orderFoodsList);
    

    /**
     * 通过订单记录主键删除订单商品信息
     * 
     * @param id 订单记录ID
     * @return 结果
     */
    public int deleteOrderFoodsByOid(String id);
}
